const { exec } = require('child_process');
const fs = require('fs');
const path = require('path');
/**
 * Execute simple shell command (async wrapper).
 * @param {String} cmd
 * @return {Object} { stdout: String, stderr: String }
 */
async function sh(cmd) {
    return new Promise(function (resolve, reject) {
        exec(cmd, (err, stdout, stderr) => {
            if (err) {
                console.log(err);
                reject({ err, stdout, stderr });
            } else {
                console.log(stdout)
                console.log(stderr)
                resolve({ stdout, stderr });
            }
        });
    });
}

async function main() {
    // 读取CHANGELOG.md，如果已存在当前版本的内容，则不更新
    const data = fs.readFileSync(path.join(__dirname, '..', 'CHANGELOG.md'), "utf-8");
    if (data.indexOf(`<a name="${process.env.npm_package_version}"></a>`)) {
        // 生成changelog
        await sh('npm run changelog');
        // commit
        await sh('git add -A');
        await sh(`git commit -m "docs: release v${process.env.npm_package_version}"`);
        await sh(`git tag v${process.env.npm_package_version}`);
        await sh(`git push origin master v${process.env.npm_package_version}`);
        // 发布
        var dir = path.join(__dirname, '..', 'lib');
        if (!fs.existsSync(dir)) {
            fs.mkdirSync(dir);
            fs.writeFileSync(path.join(dir, 'temp.txt'), 'Placeholder');
        }
        await sh('npm run build');
        await sh("npm publish")
        
    }
}

main();